# Generated by Django 5.0.6 on 2025-04-04 14:56

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_location", "0003_region_code"),
    ]

    operations = [
        migrations.CreateModel(
            name="Currency",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        help_text="Created at",
                        verbose_name="Created at",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True, help_text="Updated at", verbose_name="Updated at"
                    ),
                ),
                (
                    "status",
                    models.BooleanField(
                        default=True, help_text="Status", verbose_name="Status"
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        help_text="Currency name",
                        max_length=100,
                        verbose_name="Currency name",
                    ),
                ),
                (
                    "code",
                    models.CharField(
                        help_text="Currency code",
                        max_length=10,
                        verbose_name="Currency code",
                    ),
                ),
                (
                    "simbol",
                    models.CharField(
                        help_text="Currency symbol",
                        max_length=10,
                        verbose_name="Currency symbol",
                    ),
                ),
                (
                    "description",
                    models.CharField(
                        help_text="Currency description",
                        max_length=100,
                        verbose_name="Currency description",
                    ),
                ),
                (
                    "country",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="+",
                        to="artd_location.country",
                    ),
                ),
            ],
            options={
                "verbose_name": "Currency",
                "verbose_name_plural": "Currencies",
            },
        ),
    ]
