# Generated by Django 5.0.6 on 2025-04-04 14:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("artd_location", "0004_currency"),
    ]

    operations = [
        migrations.RenameField(
            model_name="currency",
            old_name="simbol",
            new_name="symbol",
        ),
    ]
