from django.utils.translation import gettext_lazy as _

CURRENCIES = [
    {
        "name": _("Peso Argentino"),
        "code": "ARS",
        "symbol": "$",
        "country": 12,
    },
    {
        "name": _("Boliviano"),
        "code": "BOB",
        "symbol": "Bs.",
        "country": 28,
    },
    {
        "name": _("Real Brasileño"),
        "code": "BRL",
        "symbol": "R$",
        "country": 31,
    },
    {
        "name": _("Peso Chileno"),
        "code": "CLP",
        "symbol": "$",
        "country": 41,
    },
    {
        "name": _("Peso Colombiano"),
        "code": "COP",
        "symbol": "$",
        "country": 45,
    },
    {
        "name": _("Colón Costarricense"),
        "code": "CRC",
        "symbol": "₡",
        "country": 52,
    },
    {
        "name": _("Peso Cubano"),
        "code": "CUP",
        "symbol": "$",
        "country": 54,
    },
    {
        "name": _("Dólar Estadounidense"),
        "code": "USD",
        "symbol": "$",
        "country": 57,
    },
    {
        "name": _("Quetzal"),
        "code": "GTQ",
        "symbol": "Q",
        "country": 82,
    },
    {
        "name": _("Lempira"),
        "code": "HNL",
        "symbol": "L",
        "country": 90,
    },
    {
        "name": _("Peso Mexicano"),
        "code": "MXN",
        "symbol": "$",
        "country": 141,
    },
    {
        "name": _("Córdoba Nicaragüense"),
        "code": "NIO",
        "symbol": "C$",
        "country": 164,
    },
    {
        "name": _("Balboa"),
        "code": "PAB",
        "symbol": "B/.",
        "country": 176,
    },
    {
        "name": _("Guaraní"),
        "code": "PYG",
        "symbol": "₲",
        "country": 178,
    },
    {
        "name": _("Sol Peruano"),
        "code": "PEN",
        "symbol": "S/",
        "country": 179,
    },
    {
        "name": _("Peso Dominicano"),
        "code": "DOP",
        "symbol": "RD$",
        "country": 188,
    },
    {
        "name": _("Peso Uruguayo"),
        "code": "UYU",
        "symbol": "$",
        "country": 237,
    },
    {
        "name": _("Bolívar"),
        "code": "VES",
        "symbol": "Bs.",
        "country": 240,
    },
]
