# Generated by Django 5.0.6 on 2025-04-02 20:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_location", "0002_alter_city_created_at_alter_city_status_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="region",
            name="code",
            field=models.CharField(
                blank=True,
                help_text="Region code",
                max_length=10,
                null=True,
                verbose_name="Region code",
            ),
        ),
    ]
